@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 """
 The idea of MultilingualManager is taken from
 django-linguo by Zach Mathew
@@ -6,23 +5,24 @@ django-linguo by Zach Mathew
 https://github.com/zmathew/django-linguo
 """
 import itertools
+from functools import reduce
 
 from django import VERSION
 from django.contrib.admin.utils import get_model_from_relation
 from django.core.exceptions import FieldDoesNotExist
 from django.db import models
-from django.db.models.query import ValuesIterable
-from django.utils.tree import Node
-from django.db.models.lookups import Lookup
 from django.db.models.expressions import Col
-from six import moves
+from django.db.models.lookups import Lookup
+from django.db.models.query import QuerySet, ValuesIterable
+from django.db.models.utils import create_namedtuple_class
+from django.utils.tree import Node
 
-from modeltranslation import settings
 from modeltranslation.fields import TranslationField
+from modeltranslation.thread_context import auto_populate_mode
 from modeltranslation.utils import (
+    auto_populate,
     build_localized_fieldname,
     get_language,
-    auto_populate,
     resolution_order,
 )
 
@@ -122,7 +122,7 @@ def append_lookup_keys(model, fields):
             new_field = (field,)
         new_fields.append(new_field)
 
-    return moves.reduce(set.union, new_fields, set())
+    return reduce(set.union, new_fields, set())
 
 
 def rewrite_order_lookup_key(model, lookup_key):
@@ -172,7 +172,7 @@ def get_field_by_colum_name(model, col):
     assert False, "No field found for column %s" % col
 
 
-class MultilingualQuerySet(models.query.QuerySet):
+class MultilingualQuerySet(QuerySet):
     def __init__(self, *args, **kwargs):
         super(MultilingualQuerySet, self).__init__(*args, **kwargs)
         self._post_init()
@@ -180,7 +180,7 @@ class MultilingualQuerySet(models.query.QuerySet):
     def _post_init(self):
         self._rewrite = True
         self._populate = None
-        if self.model and (not self.query.order_by):
+        if self.model and self.query.default_ordering and (not self.query.order_by):
             if self.model._meta.ordering:
                 # If we have default ordering specified on the model, set it now so that
                 # it can be rewritten. Otherwise sql.compiler will grab it directly from _meta
@@ -203,8 +203,6 @@ class MultilingualQuerySet(models.query.QuerySet):
         kwargs.setdefault('_populate', self._populate)
         if hasattr(self, 'translation_fields'):
             kwargs.setdefault('translation_fields', self.translation_fields)
-        if hasattr(self, 'fields_to_del'):
-            kwargs.setdefault('fields_to_del', self.fields_to_del)
         if hasattr(self, 'original_fields'):
             kwargs.setdefault('original_fields', self.original_fields)
         cloned = super(MultilingualQuerySet, self)._clone()
@@ -378,7 +376,7 @@ class MultilingualQuerySet(models.query.QuerySet):
     def _populate_mode(self):
         # Populate can be set using a global setting or a manager method.
         if self._populate is None:
-            return settings.AUTO_POPULATE
+            return auto_populate_mode()
         return self._populate
 
     # This method was not present in django-linguo
@@ -408,8 +406,8 @@ class MultilingualQuerySet(models.query.QuerySet):
         return super(MultilingualQuerySet, self).only(*fields)
 
     # This method was not present in django-linguo
-    def raw_values(self, *fields):
-        return super(MultilingualQuerySet, self).values(*fields)
+    def raw_values(self, *fields, **expressions):
+        return super(MultilingualQuerySet, self).values(*fields, **expressions)
 
     def _values(self, *original, **kwargs):
         selects_all = kwargs.pop('selects_all', False)
@@ -421,7 +419,6 @@ class MultilingualQuerySet(models.query.QuerySet):
         clone = super(MultilingualQuerySet, self)._values(*list(new_fields), **kwargs)
         clone.original_fields = tuple(original)
         clone.translation_fields = translation_fields
-        clone.fields_to_del = new_fields - annotation_keys - set(original)
         return clone
 
     # This method was not present in django-linguo
@@ -432,28 +429,50 @@ class MultilingualQuerySet(models.query.QuerySet):
         if not fields:
             # Emulate original queryset behaviour: get all fields that are not translation fields
             fields = self._get_original_fields()
+        fields += tuple(expressions)
         clone = self._values(*fields, prepare=True, selects_all=selects_all, **expressions)
         clone._iterable_class = FallbackValuesIterable
         return clone
 
     # This method was not present in django-linguo
-    def values_list(self, *fields, **kwargs):
+    def values_list(self, *fields, flat=False, named=False):
         if not self._rewrite:
-            return super(MultilingualQuerySet, self).values_list(*fields, **kwargs)
-        flat = kwargs.pop('flat', False)
-        if kwargs:
-            raise TypeError('Unexpected keyword arguments to values_list: %s' % (list(kwargs),))
+            return super(MultilingualQuerySet, self).values_list(*fields, flat=flat, named=named)
+        if flat and named:
+            raise TypeError("'flat' and 'named' can't be used together.")
         if flat and len(fields) > 1:
             raise TypeError(
-                "'flat' is not valid when values_list is " "called with more than one field."
+                "'flat' is not valid when values_list is called with more than one field."
             )
         selects_all = not fields
         if not fields:
             # Emulate original queryset behaviour: get all fields that are not translation fields
             fields = self._get_original_fields()
-        clone = self._values(*fields, prepare=True, selects_all=selects_all)
+
+        field_names = {f for f in fields if not hasattr(f, 'resolve_expression')}
+        _fields = []
+        expressions = {}
+        counter = 1
+        for field in fields:
+            if hasattr(field, 'resolve_expression'):
+                field_id_prefix = getattr(field, 'default_alias', field.__class__.__name__.lower())
+                while True:
+                    field_id = field_id_prefix + str(counter)
+                    counter += 1
+                    if field_id not in field_names:
+                        break
+                expressions[field_id] = field
+                _fields.append(field_id)
+            else:
+                _fields.append(field)
+
+        clone = self._values(*_fields, prepare=True, selects_all=selects_all, **expressions)
         clone._iterable_class = (
-            FallbackFlatValuesListIterable if flat else FallbackValuesListIterable
+            FallbackNamedValuesListIterable
+            if named
+            else FallbackFlatValuesListIterable
+            if flat
+            else FallbackValuesListIterable
         )
         return clone
 
@@ -472,21 +491,31 @@ class FallbackValuesIterable(ValuesIterable):
 
     def __iter__(self):
         instance = self.X()
-        for row in super(FallbackValuesIterable, self).__iter__():
+
+        fields = self.queryset.original_fields
+        fields += tuple(f for f in self.queryset.query.annotation_select if f not in fields)
+
+        for row in super().__iter__():
             instance.__dict__.update(row)
             for key in self.queryset.translation_fields:
                 row[key] = getattr(self.queryset.model, key).__get__(instance, None)
-            for key in self.queryset.fields_to_del:
-                del row[key]
-            yield row
+            # Restore original ordering.
+            yield {k: row[k] for k in fields}
 
 
 class FallbackValuesListIterable(FallbackValuesIterable):
     def __iter__(self):
-        fields = self.queryset.original_fields
-        fields += tuple(f for f in self.queryset.query.annotation_select if f not in fields)
-        for row in super(FallbackValuesListIterable, self).__iter__():
-            yield tuple(row[f] for f in fields)
+        for row in super().__iter__():
+            yield tuple(row.values())
+
+
+class FallbackNamedValuesListIterable(FallbackValuesIterable):
+    def __iter__(self):
+        for row in super().__iter__():
+            names, values = row.keys(), row.values()
+            tuple_class = create_namedtuple_class(*names)
+            new = tuple.__new__
+            yield new(tuple_class, values)
 
 
 class FallbackFlatValuesListIterable(FallbackValuesListIterable):
